AnalyticsConfig class
Configuration for the Applytics client
Constructors
Properties
- apiKey → String
-
API key for authentication
final
- batchSize → int
-
Batch size - number of events to accumulate before sending
final
- debug → bool
-
Enable debug logging
final
- enableSessionTracking → bool
-
Enable automatic session tracking
final
- flushIntervalSeconds → int
-
Flush interval in seconds - how often to send batched events
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutSeconds → int
-
Timeout for API requests in seconds
final
Methods
-
copyWith(
{String? apiUrl, String? apiKey, bool? debug, int? batchSize, int? flushIntervalSeconds, int? timeoutSeconds, bool? enableSessionTracking}) → AnalyticsConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited